@@ -12,7 +12,7 @@ use HTTP::Tiny;
 use Time::HiRes;
 use String::Similarity qw(similarity);
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # Litchfield  38887 38888   City of Santa Rosa Laguna Treatment Plant 22961 22962    Geek Orchard 26363 26364
 
@@ -105,7 +105,7 @@ Set to $@ when an exception is caught (for instance, when a JSON string does not
 
 =item C<js_or> (C<JSON::MaybeXS> object reference)
 
-Contains a reference to the JSON decoder object used internally.  May be overridden by the user when different behavior is desired.  The default instance has parameters C<ascii => 1, allow_nonref => 1, space_after => 1>.
+Contains a reference to the JSON decoder object used internally.  May be overridden by the user when different behavior is desired.  The default instance has parameters C<ascii =E<gt> 1, allow_nonref =E<gt> 1, space_after =E<gt> 1>.
 
 =back
 
@@ -151,9 +151,9 @@ should have in the guessed metric.
 
 For example:
 
-    { GUESSING => [123.45, 1.09]}  # AQI is 123.45, with high confidence
-    { GUESSING => [123.45, 10.3]}  # AQI is 123.45, with somewhat less confidence
-    { GUESSING => [123.45, 67.5]}  # AQI is 123.45, with very low confidence!
+    { GUESSING =E<gt> [123.45, 1.09]}  # AQI is 123.45, with high confidence
+    { GUESSING =E<gt> [123.45, 10.3]}  # AQI is 123.45, with somewhat less confidence
+    { GUESSING =E<gt> [123.45, 67.5]}  # AQI is 123.45, with very low confidence!
 
 Default is 0 (do not guess).
 
@@ -390,7 +390,7 @@ sub sensor_url {
 
 =head2 C<report([sensor-id, sensor-id, ...])>
 
-=head2 C<report([sensor-id, sensor-id, ...], {option => value, ...})>
+=head2 C<report([sensor-id, sensor-id, ...], {option =E<gt> value, ...})>
 
 =over 4
 
@@ -398,7 +398,7 @@ The C<report> method retrieves current data from each specified sensor and retur
 sensor name keys and arrayref values.  The values represent the air quality at the sensor's location 
 (where higher values = more gunk in the air).  Higher than 50 is bad, lower than 20 is good.
 
-If no list of sensor IDs is used, and no list was provided to C<new(sensor => ...)> a default of 
+If no list of sensor IDs is used, and no list was provided to C<new(sensor =E<gt> ...)> a default of 
 25407 (Gravenstein School) will be used, which probably is not very useful to you.
 
 See the notes under C<sensor> in the section for C<new> regarding sensor IDs and how to find them.
@@ -411,17 +411,6 @@ Returns a hashref as described on success and sets the object's C<ok> and C<err>
 
 =back
 
-=head1 AUTHOR
-
-TTK Ciar, <ttk[at]ciar[dot]org>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright 2020 by TTK Ciar
-
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
-
 =cut
 
 sub report {
@@ -650,6 +639,17 @@ smoking near the sensor can produce a false high reading.  Right now the
 workaround is to specify multiple sensors and use the -g option.  Future
 releases will provide alternative remedies.
 
+=head1 AUTHOR
+
+TTK Ciar, <ttk[at]ciar[dot]org>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2020 by TTK Ciar
+
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
 =head1 TO DO
 
 Write more documentation.  Some methods are undocumented.
